@@ -179,21 +179,6 @@ class BaseTask(Component):
         """
         return chs >> self
 
-    @classmethod
-    def source_code(cls) -> str:
-        import inspect
-        return inspect.getsource(cls)
-
-    @classmethod
-    def input_signature(cls) -> dict:
-        call_signature = {
-            param: str(param_type)
-            for param, param_type
-            in inspect.signature(cls.__call__).parameters.items()
-        }
-
-        return call_signature
-
     def serialize(self) -> TaskInput:
         # TODO can not fetch source code of type(self), if it's due to makefun ?
         config = self.config
@@ -223,6 +208,7 @@ class RunTask(BaseTask):
     default_config = {
         'drop_error': False,
         'retry': 0,
+        'retry_delay': 5,
         'fork': 7,
         'cpu': 1,
         'gpu': 0,
@@ -362,7 +348,7 @@ class RunTask(BaseTask):
         """
         from copy import copy
         clean_task = copy(self)
-        res = clean_task.run(**data.arguments)
+        res = clean_task.run(*data.args, **data.kwargs)
         return res
 
     async def handle_res(self, res):
@@ -515,18 +501,18 @@ class Task(RunTask):
             raise res.result
         # for Drop, just ignore it
 
-    def need_skip(self, bound_args: BoundArguments) -> bool:
+    def need_skip(self, data: BoundArguments) -> bool:
         """ Check if the _input can be directly passed into _output channels by predicate of user specified self.skip_fn
         Parameters
         ----------
-        bound_args
+        data
 
         Returns
         -------
 
         """
         if self.skip_fn:
-            return self.skip_fn(**bound_args.arguments)
+            return self.skip_fn(*data.args, **data.kwargs)
         else:
             return False
 
